@@ -1,7 +1,6 @@
-from bergen.types.manager import  ModelManager
-from bergen.types.model import ArnheimAsyncModelManager
+from bergen.types.model import ArnheimAsyncModelManager, ArnheimModelManager
 
-class RepresentationManager(ModelManager):
+class RepresentationManager(ArnheimModelManager["Representation"]):
 
     def from_xarray(self, array, compute=True, **kwargs):
         instance = self.create(**kwargs)
