@@ -1,12 +1,20 @@
 from grunnlag.gql.sample import CREATE_SAMPLE, FILTER_SAMPLE, GET_SAMPLE
 from grunnlag.gql.representation import CREATE_REPRESENTATION, GET_REPRESENTATION, UPDATE_REPRESENTATION, FILTER_REPRESENTATION
-from grunnlag.managers import RepresentationManager
-from typing import ForwardRef, List, Optional
+from grunnlag.managers import AsyncRepresentationManager, RepresentationManager
+from typing import List, Optional
 from bergen.types.model import ArnheimModel
 from bergen.schema import User
 from grunnlag.extenders import Array, RepresentationPrettifier
+try:
+	# python 3.8
+	from typing import ForwardRef
+except ImportError:
+	# ForwardRef is private in python 3.6 and 3.7
+	from typing import _ForwardRef as ForwardRef
+
 
 Representation = ForwardRef("Representation")
+Sample = ForwardRef("Sample")
 
 
 class Representation(RepresentationPrettifier, Array, ArnheimModel):
@@ -17,8 +25,10 @@ class Representation(RepresentationPrettifier, Array, ArnheimModel):
     shape: Optional[List[int]]
     image: Optional[str]
     unique: Optional[str]
+    sample: Optional[Sample]
 
     objects = RepresentationManager()
+    asyncs = AsyncRepresentationManager()
 
     class Meta:
         identifier = "representation"
@@ -44,4 +54,5 @@ class Sample(ArnheimModel):
 
 
 Representation.update_forward_refs()
+Sample.update_forward_refs()
 
